==> vue-option-2.21.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/option/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { AutoTip } from '@opentinyvue/vue-directive';
import { iconCheck, iconCheckedSur, iconFinish } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible && _vm.state.visible,
      expression: "visible && state.visible"
    }],
    ref: "option",
    class: _vm.m("h-fit flex items-center justify-between rounded text-color-text-primary text-sm sm:text-xs", "min-h-[40px] sm:min-h-[32px] cursor-pointer group sm:hover:bg-color-bg-4 sm:active:bg-color-bg-3 pl-0 pr-3 sm:px-3 my-1 sm:m-1", {
      "text-color-brand bg-color-bg-1 sm:bg-color-fill-6": _vm.state.itemSelected && !_vm.disabled,
      "text-color-text-disabled cursor-not-allowed [&_svg]:fill-color-icon-disabled [&_svg_path:first-of-type]:fill-color-bg-3": _vm.disabled || _vm.state.groupDisabled || _vm.state.limitReached,
      "bg-color-bg-1 sm:bg-color-bg-4": _vm.state.hover,
      "text-color-text-disabled cursor-not-allowed": _vm.required
    }, _vm.highlightClass),
    attrs: {
      "data-index": _vm.state.index,
      "data-tag": "tiny-option"
    },
    on: {
      "mouseenter": _vm.hoverItem,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.selectOptionClick.apply(null, arguments);
      },
      "mousedown": function mousedown($event) {
        $event.stopPropagation();
      }
    }
  }, [_vm.state.selectMultiple ? _c("span", {
    staticClass: "w-4 mr-2"
  }, [_c("icon-" + _vm.state.selectCls, {
    tag: "component",
    class: _vm.m("fill-color-icon-secondary relative", {
      "group-hover:fill-color-brand-hover": _vm.state.hover,
      "fill-color-brand": _vm.state.itemSelected,
      "fill-color-brand-disabled": _vm.state.itemSelected && _vm.required
    })
  })], 1) : _vm._e(), _vm._t("default", function() {
    return [_c("span", {
      directives: [{
        name: "auto-tip",
        rawName: "v-auto-tip",
        value: {
          placement: "right"
        },
        expression: "{ placement: 'right' }"
      }],
      staticClass: "inline-block flex-1 leading-5 overflow-hidden text-ellipsis whitespace-normal sm:whitespace-nowrap"
    }, [_vm._v(_vm._s(_vm.state.currentLabel))])];
  }), !_vm.state.selectMultiple && _vm.state.itemSelected && !_vm.disabled && !_vm.state.groupDisabled ? _c("span", {
    staticClass: "inline-block sm:hidden w-4 ml-4 shrink-0"
  }, [_c("icon-finish", {
    attrs: {
      "custom-class": "w-4 h-4 fill-color-brand"
    }
  })], 1) : _vm._e()], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  directives: {
    AutoTip
  },
  components: {
    IconCheck: iconCheck(),
    IconCheckedSur: iconCheckedSur(),
    IconFinish: iconFinish()
  },
  props: [].concat(props, ["value", "label", "created", "disabled", "events", "visible", "highlightClass", "required"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };

==> vue-option-2.24.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/option/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import { AutoTip } from '@opentinyvue/vue-directive';
import { iconCheck, iconCheckedSur, iconFinish } from '@opentinyvue/vue-icon';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    directives: [{
      name: "show",
      rawName: "v-show",
      value: _vm.visible && _vm.state.visible,
      expression: "visible && state.visible"
    }],
    ref: "option",
    class: _vm.m("h-fit flex items-center justify-between rounded text-color-text-primary text-sm sm:text-xs", "min-h-[40px] sm:min-h-[32px] cursor-pointer group sm:hover:bg-color-bg-4 sm:active:bg-color-bg-3 pl-0 pr-3 sm:px-2 my-1 sm:m-1", {
      "text-color-brand bg-color-bg-1 sm:bg-color-fill-6": _vm.state.itemSelected && !_vm.disabled,
      "text-color-text-disabled cursor-not-allowed [&_svg]:fill-color-icon-disabled [&_svg_path:first-of-type]:fill-color-bg-3": _vm.disabled || _vm.state.groupDisabled || _vm.state.limitReached,
      "bg-color-bg-1 sm:bg-color-bg-4": _vm.state.hover,
      "text-color-text-disabled cursor-not-allowed": _vm.required
    }, _vm.highlightClass),
    attrs: {
      "data-index": _vm.state.index,
      "data-tag": "tiny-option"
    },
    on: {
      "mouseenter": _vm.hoverItem,
      "click": function click($event) {
        $event.stopPropagation();
        return _vm.selectOptionClick.apply(null, arguments);
      },
      "mousedown": function mousedown($event) {
        $event.stopPropagation();
      }
    }
  }, [_vm.state.selectMultiple ? _c("span", {
    staticClass: "w-4 mr-2"
  }, [_c("icon-" + _vm.state.selectCls, {
    tag: "component",
    class: _vm.m("fill-color-icon-secondary relative w-3.5 h-3.5", {
      "group-hover:fill-color-brand-hover": _vm.state.hover,
      "fill-color-brand text-color-brand": _vm.state.itemSelected,
      "fill-color-brand-disabled": _vm.state.itemSelected && _vm.required
    })
  })], 1) : _vm._e(), _vm._t("default", function() {
    return [_c("span", {
      directives: [{
        name: "auto-tip",
        rawName: "v-auto-tip",
        value: {
          placement: "right"
        },
        expression: "{ placement: 'right' }"
      }],
      staticClass: "inline-block flex-1 leading-5 overflow-hidden text-ellipsis whitespace-normal sm:whitespace-nowrap"
    }, [_vm._v(_vm._s(_vm.state.currentLabel))])];
  }), !_vm.state.selectMultiple && _vm.state.itemSelected && !_vm.disabled && !_vm.state.groupDisabled ? _c("span", {
    staticClass: "inline-block sm:hidden w-4 ml-4 shrink-0"
  }, [_c("icon-finish", {
    attrs: {
      "custom-class": "w-3.5 h-3.5 fill-color-brand"
    }
  })], 1) : _vm._e()], 2);
};
var staticRenderFns = [];
var __vue2_script = defineComponent({
  directives: {
    AutoTip
  },
  components: {
    IconCheck: iconCheck(),
    IconCheckedSur: iconCheckedSur(),
    IconFinish: iconFinish()
  },
  props: [].concat(props, ["value", "label", "created", "disabled", "events", "visible", "highlightClass", "required"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
